@@ -1,3 +1,40 @@
+#' Combine two time series in one
+#'
+#' The function combines several ts vectors in one, maintaining the structure
+#' of the time series
+#'
+#' The function will combine ts objects in a ts vector, using the frequency and the start of
+#' the first one. So, if you combine several time series, they will be stacked one after
+#' another.
+#'
+#' @template author
+#'
+#' @param ...  The ts vectors to combine.
+#' @return This function returns the ts vector.
+#' @seealso \link[base]{c}
+#' @keywords htest
+#' @examples
+#'
+#' x <- ts(rnorm(120,100,10), frequency=12)
+#' x1 <- window(x, 1, 8+11/12)
+#' x2 <- window(x, 9)
+#' c(x1,x2)
+#' c(x2,x1)
+#'
+#' @export
+c.ts <- function(...){
+    ellipsis <- list(...);
+    # tsFrequencies <- sapply(ellipsis, frequency);
+    # startTimes <- sapply(lapply(ellipsis, time), min);
+    # tsOrders <- order(startTimes);
+    # startTimes <- startTimes[tsOrders];
+    # if(any(tsOrders!=c(1:length(tsOrders)))){
+    #     ellipsis <- ellipsis[tsOrders];
+    # }
+
+    return(ts(unlist(ellipsis), start=start(ellipsis[[1]]), frequency=frequency(ellipsis[[1]])));
+}
+
 ##### IC functions #####
 
 #' Corrected Akaike's Information Criterion and Bayesian Information Criterion
@@ -901,6 +938,13 @@ predict.greybox <- function(object, newdata=NULL, interval=c("none", "confidence
     if(is.null(newdata)){
         matrixOfxreg <- object$data;
         newdataProvided <- FALSE;
+        # The first column is the response variable. Either substitute it by ones or remove it.
+        if(any(parametersNames=="(Intercept)")){
+            matrixOfxreg[,1] <- 1;
+        }
+        else{
+            matrixOfxreg <- matrixOfxreg[,-1];
+        }
     }
     else{
         newdataProvided <- TRUE;
@@ -1650,7 +1694,7 @@ print.mcor <- function(x, ...){
 print.summary.alm <- function(x, ...){
     ellipsis <- list(...);
     if(!any(names(ellipsis)=="digits")){
-        digits <- 5;
+        digits <- 4;
     }
     else{
         digits <- ellipsis$digits;
@@ -1688,20 +1732,19 @@ print.summary.alm <- function(x, ...){
     }
     cat("\nCoefficients:\n");
     print(round(x$coefficients,digits));
-    cat("ICs:\n");
-    print(round(x$ICs,digits));
     cat("\nError standard deviation: "); cat(round(sqrt(x$s2),digits));
     cat("\nSample size: "); cat(x$dfTable[1]);
     cat("\nNumber of estimated parameters: "); cat(x$dfTable[2]);
     cat("\nNumber of degrees of freedom: "); cat(x$dfTable[3]);
-    cat("\n");
+    cat("\nInformation criteria:\n");
+    print(round(x$ICs,digits));
 }
 
 #' @export
 print.summary.greybox <- function(x, ...){
     ellipsis <- list(...);
     if(!any(names(ellipsis)=="digits")){
-        digits <- 5;
+        digits <- 4;
     }
     else{
         digits <- ellipsis$digits;
@@ -1732,22 +1775,19 @@ print.summary.greybox <- function(x, ...){
     }
     cat("\nCoefficients:\n");
     print(round(x$coefficients,digits));
-    cat("---\n");
-    cat(paste0("Residual standard error: ",round(x$sigma,digits)," on ",
-               round(x$df[2],digits)," degrees of freedom:\n"));
-    cat("ICs:\n");
-    print(round(x$ICs,digits));
+    cat("\nError standard deviation: "); cat(round(x$sigma,digits));
     cat("\nSample size: "); cat(x$dfTable[1]);
     cat("\nNumber of estimated parameters: "); cat(x$dfTable[2]);
     cat("\nNumber of degrees of freedom: "); cat(x$dfTable[3]);
-    cat("\n");
+    cat("Information criteria:\n");
+    print(round(x$ICs,digits));
 }
 
 #' @export
 print.summary.greyboxC <- function(x, ...){
     ellipsis <- list(...);
     if(!any(names(ellipsis)=="digits")){
-        digits <- 5;
+        digits <- 4;
     }
     else{
         digits <- ellipsis$digits;
@@ -1775,15 +1815,12 @@ print.summary.greyboxC <- function(x, ...){
     cat(paste0("Distribution used in the estimation: ", distrib));
     cat("\nCoefficients:\n");
     print(round(x$coefficients,digits));
-    cat("---\n");
-    cat(paste0("Residual standard error: ",round(x$sigma,digits)," on ",
-               round(x$df[2],digits)," degrees of freedom:\n"));
-    cat("Approximate combined ICs:\n");
+    cat("\nError standard deviation: "); cat(round(x$sigma,digits));
+    cat("\nSample size: "); cat(round(x$dfTable[1],digits));
+    cat("\nNumber of estimated parameters: "); cat(round(x$dfTable[2],digits));
+    cat("\nNumber of degrees of freedom: "); cat(round(x$dfTable[3],digits));
+    cat("\nApproximate combined information criteria:\n");
     print(round(x$ICs,digits));
-    cat("\nSample size: "); cat(x$dfTable[1]);
-    cat("\nNumber of estimated parameters: "); cat(x$dfTable[2]);
-    cat("\nNumber of degrees of freedom: "); cat(x$dfTable[3]);
-    cat("\n");
 }
 
 #' @export
@@ -2007,7 +2044,7 @@ vcov.alm <- function(object, ...){
         vcovMatrixTry <- try(chol2inv(chol(matrixXreg)), silent=TRUE);
         if(class(vcovMatrixTry)=="try-error"){
             warning(paste0("Choleski decomposition of covariance matrix failed, so we had to revert to the simple inversion.\n",
-                           "The estimate of the covariance matrix of parameters might be inacurate."),
+                           "The estimate of the covariance matrix of parameters might be inaccurate."),
                     call.=FALSE);
             vcovMatrix <- try(solve(matrixXreg, diag(nVariables), tol=1e-20), silent=TRUE);
             if(class(vcovMatrix)=="try-error"){
@@ -2036,7 +2073,7 @@ vcov.alm <- function(object, ...){
         vcovMatrixTry <- try(chol2inv(chol(matrixXreg)), silent=TRUE);
         if(class(vcovMatrixTry)=="try-error"){
             warning(paste0("Choleski decomposition of covariance matrix failed, so we had to revert to the simple inversion.\n",
-                           "The estimate of the covariance matrix of parameters might be inacurate."),
+                           "The estimate of the covariance matrix of parameters might be inaccurate."),
                     call.=FALSE);
             vcovMatrix <- try(solve(matrixXreg, diag(nVariables), tol=1e-20), silent=TRUE);
             if(class(vcovMatrix)=="try-error"){
